@@ -1,19 +1,18 @@
 import os
 import gensim
-import numpy
+import numpy as np
 import pytest
 from matchms import Spectrum
-from spec2vec import Spec2Vec
-from spec2vec import SpectrumDocument
+from spec2vec import Spec2Vec, SpectrumDocument
 
 
 def test_spec2vec_pair_method_spectrum_entry():
     """Test if pair of two Spectrums is handled correctly"""
-    spectrum_1 = Spectrum(mz=numpy.array([100, 150, 200.]),
-                          intensities=numpy.array([0.7, 0.2, 0.1]),
+    spectrum_1 = Spectrum(mz=np.array([100, 150, 200.]),
+                          intensities=np.array([0.7, 0.2, 0.1]),
                           metadata={'id': 'spectrum1'})
-    spectrum_2 = Spectrum(mz=numpy.array([100, 140, 190.]),
-                          intensities=numpy.array([0.4, 0.2, 0.1]),
+    spectrum_2 = Spectrum(mz=np.array([100, 140, 190.]),
+                          intensities=np.array([0.4, 0.2, 0.1]),
                           metadata={'id': 'spectrum2'})
 
     model = load_test_model()
@@ -26,11 +25,11 @@ def test_spec2vec_pair_method_spectrum_entry():
 
 def test_spec2vec_pair_method_spectrumdocument_entry():
     """Test if pair of two SpectrumDocuments is handled correctly"""
-    spectrum_1 = Spectrum(mz=numpy.array([100, 150, 200.]),
-                          intensities=numpy.array([0.7, 0.2, 0.1]),
+    spectrum_1 = Spectrum(mz=np.array([100, 150, 200.]),
+                          intensities=np.array([0.7, 0.2, 0.1]),
                           metadata={'id': 'spectrum1'})
-    spectrum_2 = Spectrum(mz=numpy.array([100, 140, 190.]),
-                          intensities=numpy.array([0.4, 0.2, 0.1]),
+    spectrum_2 = Spectrum(mz=np.array([100, 140, 190.]),
+                          intensities=np.array([0.4, 0.2, 0.1]),
                           metadata={'id': 'spectrum2'})
 
     documents = [SpectrumDocument(s, n_decimals=1) for s in [spectrum_1, spectrum_2]]
@@ -44,8 +43,8 @@ def test_spec2vec_pair_method_spectrumdocument_entry():
 
 def test_spec2vec_pair_method_none_entry():
     """Test if wrong input data raises expected exception"""
-    spectrum_1 = Spectrum(mz=numpy.array([100, 150, 200.]),
-                          intensities=numpy.array([0.7, 0.2, 0.1]),
+    spectrum_1 = Spectrum(mz=np.array([100, 150, 200.]),
+                          intensities=np.array([0.7, 0.2, 0.1]),
                           metadata={'id': 'spectrum1'})
     spectrum_2 = None
     model = load_test_model()
@@ -59,11 +58,11 @@ def test_spec2vec_pair_method_none_entry():
 
 def test_spec2vec_pair_method_wrong_spectrumdocument_entry():
     """Test if SpectrumDocuments with different decimal rounding is handled correctly"""
-    spectrum_1 = Spectrum(mz=numpy.array([100, 150, 200.]),
-                          intensities=numpy.array([0.7, 0.2, 0.1]),
+    spectrum_1 = Spectrum(mz=np.array([100, 150, 200.]),
+                          intensities=np.array([0.7, 0.2, 0.1]),
                           metadata={'id': 'spectrum1'})
-    spectrum_2 = Spectrum(mz=numpy.array([100, 140, 190.]),
-                          intensities=numpy.array([0.4, 0.2, 0.1]),
+    spectrum_2 = Spectrum(mz=np.array([100, 140, 190.]),
+                          intensities=np.array([0.4, 0.2, 0.1]),
                           metadata={'id': 'spectrum2'})
 
     documents = [SpectrumDocument(s, n_decimals=2) for s in [spectrum_1, spectrum_2]]
@@ -81,11 +80,11 @@ def test_spec2vec_matrix_method(progress_bar):
     """Test if matrix of 2x2 SpectrumDocuments is handled correctly.
     Run with and without progress bar.
     """
-    spectrum_1 = Spectrum(mz=numpy.array([100, 150, 200.]),
-                          intensities=numpy.array([0.7, 0.2, 0.1]),
+    spectrum_1 = Spectrum(mz=np.array([100, 150, 200.]),
+                          intensities=np.array([0.7, 0.2, 0.1]),
                           metadata={'id': 'spectrum1'})
-    spectrum_2 = Spectrum(mz=numpy.array([100, 140, 190.]),
-                          intensities=numpy.array([0.4, 0.2, 0.1]),
+    spectrum_2 = Spectrum(mz=np.array([100, 140, 190.]),
+                          intensities=np.array([0.4, 0.2, 0.1]),
                           metadata={'id': 'spectrum2'})
 
     documents = [SpectrumDocument(s, n_decimals=1) for s in [spectrum_1, spectrum_2]]
@@ -102,11 +101,11 @@ def test_spec2vec_matrix_method_symmetric_spectrum_entry():
     """Test if matrix of 2x2 Spectrums is handled correctly.
     Run with is_symmetric=True.
     """
-    spectrum_1 = Spectrum(mz=numpy.array([100, 150, 200.]),
-                          intensities=numpy.array([0.7, 0.2, 0.1]),
+    spectrum_1 = Spectrum(mz=np.array([100, 150, 200.]),
+                          intensities=np.array([0.7, 0.2, 0.1]),
                           metadata={'id': 'spectrum1'})
-    spectrum_2 = Spectrum(mz=numpy.array([100, 140, 190.]),
-                          intensities=numpy.array([0.4, 0.2, 0.1]),
+    spectrum_2 = Spectrum(mz=np.array([100, 140, 190.]),
+                          intensities=np.array([0.4, 0.2, 0.1]),
                           metadata={'id': 'spectrum2'})
 
     spectrums = [spectrum_1, spectrum_2]
@@ -123,11 +122,11 @@ def test_spec2vec_matrix_method_symmetric_spectrumdocument_entry():
     """Test if matrix of 2x2 SpectrumDocuments is handled correctly.
     Run with is_symmetric=True.
     """
-    spectrum_1 = Spectrum(mz=numpy.array([100, 150, 200.]),
-                          intensities=numpy.array([0.7, 0.2, 0.1]),
+    spectrum_1 = Spectrum(mz=np.array([100, 150, 200.]),
+                          intensities=np.array([0.7, 0.2, 0.1]),
                           metadata={'id': 'spectrum1'})
-    spectrum_2 = Spectrum(mz=numpy.array([100, 140, 190.]),
-                          intensities=numpy.array([0.4, 0.2, 0.1]),
+    spectrum_2 = Spectrum(mz=np.array([100, 140, 190.]),
+                          intensities=np.array([0.4, 0.2, 0.1]),
                           metadata={'id': 'spectrum2'})
 
     documents = [SpectrumDocument(s, n_decimals=1) for s in [spectrum_1, spectrum_2]]
@@ -144,11 +143,11 @@ def test_spec2vec_matrix_method_symmetric_wrong_entry():
     """Test if matrix of 2x2 SpectrumDocuments is handled correctly.
     Run with is_symmetric=True but non symmetric entries.
     """
-    spectrum_1 = Spectrum(mz=numpy.array([100, 150, 200.]),
-                          intensities=numpy.array([0.7, 0.2, 0.1]),
+    spectrum_1 = Spectrum(mz=np.array([100, 150, 200.]),
+                          intensities=np.array([0.7, 0.2, 0.1]),
                           metadata={'id': 'spectrum1'})
-    spectrum_2 = Spectrum(mz=numpy.array([100, 140, 190.]),
-                          intensities=numpy.array([0.4, 0.2, 0.1]),
+    spectrum_2 = Spectrum(mz=np.array([100, 140, 190.]),
+                          intensities=np.array([0.4, 0.2, 0.1]),
                           metadata={'id': 'spectrum2'})
 
     documents1 = [SpectrumDocument(s, n_decimals=1) for s in [spectrum_1, spectrum_2]]
